@@ -6,6 +6,7 @@ from archinstall.tui.menu_item import MenuItem, MenuItemGroup
 from archinstall.tui.result import ResultType
 from archinstall.tui.types import Alignment, FrameProperties, FrameStyle, Orientation, PreviewStyle
 
+from ..args import arch_config_handler
 from ..hardware import GfxDriver, SysInfo
 from ..models.bootloader import Bootloader
 
@@ -47,14 +48,25 @@ def select_kernel(preset: list[str] = []) -> list[str]:
 
 def ask_for_bootloader(preset: Bootloader | None) -> Bootloader | None:
 	# Systemd is UEFI only
+	options = []
+	hidden_options = []
+	default = None
+	header = None
+
+	if arch_config_handler.args.skip_boot:
+		default = Bootloader.NO_BOOTLOADER
+	else:
+		hidden_options += [Bootloader.NO_BOOTLOADER]
+
 	if not SysInfo.has_uefi():
-		options = [Bootloader.Grub, Bootloader.Limine]
-		default = Bootloader.Grub
+		options += [Bootloader.Grub, Bootloader.Limine]
+		if not default:
+			default = Bootloader.Grub
 		header = tr('UEFI is not detected and some options are disabled')
 	else:
-		options = [b for b in Bootloader]
-		default = Bootloader.Systemd
-		header = None
+		options += [b for b in Bootloader if b not in hidden_options]
+		if not default:
+			default = Bootloader.Systemd
 
 	items = [MenuItem(o.value, value=o) for o in options]
 	group = MenuItemGroup(items)
